@@ -21,6 +21,15 @@
     -c, --checksum
         Use checksum to skip files that are the same.
 
+    --check-rsync
+        Check if files are different using *rsync*.
+        *rsync* uses basic criteria such as file size and creation and modification date.
+        This is much faster than using checksums but is only approximate.
+        *rsync* can also check based on checksum.
+
+    --temp=N
+        Temporary filename to communicate with rsync. [default: shelephant_files.txt]
+
     -k, --key=N
         Path in the YAML-file, separated by "/". [default: /]
 
@@ -67,6 +76,8 @@ def main():
 
         parser = Parser()
         parser.add_argument('-c', '--checksum', required=False, action='store_true')
+        parser.add_argument('-r', '--check-rsync', required=False, action='store_true')
+        parser.add_argument(      '--temp', required=False, default='shelephant_files.txt')
         parser.add_argument('-k', '--key', required=False, default='/')
         parser.add_argument(      '--colors', required=False, default='dark')
         parser.add_argument('-s', '--summary', required=False, action='store_true')
@@ -94,6 +105,7 @@ def main():
             src_dir = os.path.dirname(source),
             dest_dir = dest_dir,
             checksum = args.checksum,
+            check_rsync = None if not args.check_rsync else args.temp,
             quiet = args.quiet,
             force = args.force,
             print_details = not (args.force or args.summary) or args.details,
