@@ -22,6 +22,12 @@
     --scp
         Use ``scp`` instead of ``rysnc`` as backend.
 
+    --check-rsync
+        Check if files are different using *rsync*.
+        *rsync* uses basic criteria such as file size and creation and modification date.
+        This is much faster than using checksums but is only approximate.
+        *rsync* can also check based on checksum.
+
     --temp=N
         Temporary filename to communicate with rsync. [default: shelephant_files.txt]
 
@@ -75,6 +81,7 @@ def main():
         parser = Parser()
         parser.add_argument('-l', '--local', required=False)
         parser.add_argument(      '--scp', required=False, action='store_true')
+        parser.add_argument('-r', '--check-rsync', required=False, action='store_true')
         parser.add_argument(      '--temp', required=False, default='shelephant_files.txt')
         parser.add_argument(      '--colors', required=False, default='dark')
         parser.add_argument('-s', '--summary', required=False, action='store_true')
@@ -97,6 +104,7 @@ def main():
                 src_dir = data['prefix'],
                 dest_dir = os.path.dirname(source),
                 checksum = 'checksum' in data,
+                check_rsync = None if not args.check_rsync else args.temp,
                 quiet = args.quiet,
                 force = args.force,
                 print_details = not (args.force or args.summary) or args.details,
@@ -115,6 +123,7 @@ def main():
                 src_dir = data['prefix'],
                 dest_dir = os.path.dirname(source),
                 checksum = 'checksum' in data,
+                check_rsync = None if not args.check_rsync else args.temp,
                 quiet = args.quiet,
                 force = args.force,
                 print_details = not (args.force or args.summary) or args.details,
@@ -134,6 +143,7 @@ def main():
                 src_dir = data['prefix'],
                 dest_dir = os.path.dirname(source),
                 checksum = 'checksum' in data,
+                check_rsync = None if not args.check_rsync else args.temp,
                 quiet = args.quiet,
                 force = args.force,
                 print_details = not (args.force or args.summary) or args.details,
